@@ -4,7 +4,7 @@
 ###################
 #    This file change the code for python3.8 compatibility
 #    from the command line and display the result in a web interface.
-#    Copyright (C) 2021  Maurice Lambert
+#    Copyright (C) 2021, 2022  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,8 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This tool run scripts and display the result in a Web Interface.
+"""
+This tool run scripts and display the result in a Web Interface.
 
 This file change the code for python3.8 compatibility.
 
@@ -34,7 +35,7 @@ The new package is named WebScripts38.
 Impact: "log_encoding" configuration is not use.
 """
 
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -42,7 +43,8 @@ __maintainer_email__ = "mauricelambert434@gmail.com"
 __description__ = """
 This tool run scripts and display the result in a Web Interface.
 
-This file change the code for python3.8 compatibility."""
+This file change the code for python3.8 compatibility.
+"""
 __license__ = "GPL-3.0 License"
 __url__ = "https://github.com/mauricelambert/WebScripts"
 
@@ -67,7 +69,9 @@ import re
 
 def copy(directory: str, setup_filename: str) -> None:
 
-    """This function copy the WebScripts directory and the setup."""
+    """
+    This function copy the WebScripts directory and the setup.
+    """
 
     logging.warning("Copy the WebScripts directory and the setup filename...")
     copytree(path.join(directory, "WebScripts"), path.join(directory, "WebScripts38"))
@@ -77,7 +81,9 @@ def copy(directory: str, setup_filename: str) -> None:
 
 def change_setup(filename: str) -> None:
 
-    """This function change the setup.py file."""
+    """
+    This function change the setup.py file.
+    """
 
     content = open(filename).read()
     logging.warning("Change the new setup content...")
@@ -94,7 +100,9 @@ def change_setup(filename: str) -> None:
 
 def change_manifest(filename: str) -> None:
 
-    """This function change the manifest.in file."""
+    """
+    This function change the manifest.in file.
+    """
 
     content = open(filename).read()
     logging.warning("Change the new manifest content...")
@@ -107,7 +115,9 @@ def change_manifest(filename: str) -> None:
 
 def change_utils(filename: str):
 
-    """This function change the utils.py file."""
+    """
+    This function change the utils.py file.
+    """
 
     logging.warning("Change the new utils.py content...")
     content = open(filename).read()
@@ -130,7 +140,9 @@ def change_utils(filename: str):
 
 def change_WebScripts(filename: str):
 
-    """This function change the WebScripts.py file."""
+    """
+    This function change the WebScripts.py file.
+    """
 
     logging.warning("Change the new WebScripts.py content...")
     content = open(filename).read()
@@ -147,9 +159,11 @@ def change_WebScripts(filename: str):
 
 def change_subscriptable_iterator(directory: str) -> None:
 
-    """This function change subscriptable Iterators."""
+    """
+    This function change subscriptable Iterators.
+    """
 
-    regex = re.compile(r"Iterator\[\w+\]")
+    regex = re.compile(r"Iterator\[[\w,\s\[\]]+\]")
     for filename in glob.glob(
         path.join(directory, "WebScripts38", "**", "*.py"), recursive=True
     ):
@@ -163,10 +177,24 @@ def change_subscriptable_iterator(directory: str) -> None:
 
         logging.info(f"New {filename} is changed ({number} times).")
 
+    for filename in glob.glob(
+        path.join(directory, "WebScripts38", "*.py"), recursive=True
+    ):
+        content = open(filename).read()
+        logging.warning(f"Change the new {filename} content...")
+
+        new_content, number = regex.subn("Iterator", content)
+
+        with open(filename, "w") as file:
+            file.write(new_content)
+
+        logging.info(f"New {filename} is changed ({number} times).")
 
 def main():
 
-    """This function execute the file."""
+    """
+    This function execute the file.
+    """
 
     logging.debug("Set the WebScripts directory and the setup filename...")
     webscript_dir = path.join(path.dirname(__file__), "..", "..", "..")
